@@ -1069,6 +1069,8 @@ XRL_3IFF(DCSb_Compt)
 XRL_3FFF(DCSP_KN)
 XRL_3IIF(CS_FluorLine)
 XRL_3IIF(CSb_FluorLine)
+XRL_3IIF(CS_FluorShell)
+XRL_3IIF(CSb_FluorShell)
 XRL_3IIF(CS_Photo_Partial)
 XRL_3IIF(CSb_Photo_Partial)
 XRL_4IFFF(DCSP_Rayl)
