@@ -1,6 +1,11 @@
+import os
+if "EXTRA_DLL_SEARCH_PATHS" in os.environ and hasattr(os, "add_dll_directory"):
+    for path in os.environ["EXTRA_DLL_SEARCH_PATHS"].split(os.pathsep):
+        os.add_dll_directory(path)
 import unittest
 import xraylib
 
+
 class TestAtomicLevelWidth(unittest.TestCase):
     def test_Fe_K(self):
         width = xraylib.AtomicLevelWidth(26, xraylib.K_SHELL)
