@@ -1,6 +1,11 @@
+import os
+if "EXTRA_DLL_SEARCH_PATHS" in os.environ and hasattr(os, "add_dll_directory"):
+    for path in os.environ["EXTRA_DLL_SEARCH_PATHS"].split(os.pathsep):
+        os.add_dll_directory(path)
 import unittest
 import xraylib
 
+
 class TestAugerRate(unittest.TestCase):
     def test_Pb_K_L3M5(self):
         rate = xraylib.AugerRate(82, xraylib.K_L3M5_AUGER)
